def 网页协议_获取_响应文本取中间(响应对象, 文本前缀, 文本后缀, 是否打印=False):
    """
    获取响应的文本内容，并从中提取介于文本前缀和文本后缀之间的部分文本。

    参数:
        响应对象: 服务器响应对象。
        文本前缀: 前缀字符串，用于定位目标文本的起始位置。
        文本后缀: 后缀字符串，用于定位目标文本的结束位置。
        是否打印 (bool, optional): 是否打印执行结果，默认为 False。

    返回:
        str: 响应文本中位于文本前缀和文本后缀之间的部分文本。如果响应为 None、未找到匹配的文本、或出现任何异常，则返回空字符串。
    """
    try:
        if 响应对象 is not None:
            文本内容 = 响应对象.text
            起始位置 = 文本内容.find(文本前缀)
            if 起始位置 != -1:
                起始位置 += len(文本前缀)
                结束位置 = 文本内容.find(文本后缀, 起始位置)
                if 结束位置 != -1:
                    提取的文本 = 文本内容[起始位置:结束位置]
                    if 是否打印:
                        print(f"提取的文本内容:\n{提取的文本}")
                    return 提取的文本
            if 是否打印:
                print("未找到匹配的文本")
            return ''
        else:
            if 是否打印:
                print("响应对象为 None")
            return ''
    except Exception as e:
        if 是否打印:
            print(f"获取响应文本内容时出现异常: {e}")
        return ''