def 列表_去除重复(列表):
    """
    去除列表中的重复元素，并返回去重后的新列表。

    参数:
    - 列表 (list): 包含元素的列表，可以是数字，字符串

    返回:
    - 去重后的新列表 (list): 去除重复元素后的列表
    """
    try:
        去重后的新列表 = list(set(列表))
    except Exception:
        return []
    return 去重后的新列表

