def 文本_取指定变量文本行(文本, 行号):
    """
    # 示例用法
    源文本 = "这是第一行"
    行号 = 1
    文本行 = 文本_取指定变量文本行(源文本, 行号)
    print("第", 行号, "行的文本:", 文本行)
    """
    行列表 = 文本.splitlines()
    行数 = len(行列表)
    if 1 <= 行号 <= 行数:
        return 行列表[行号 - 1]
    else:
        return ""